
###
###  Copyright 2000-2005 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  PSGConf::Action::ChMod - chmod file action type for psgconf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::ChMod;

use strict;

use File::stat;

use PSGConf::Action::File;

our @ISA = qw(PSGConf::Action::File);


###############################################################################
###  check method
###############################################################################

sub check
{
	my ($self, $psgconf) = @_;

	$self->{stat} = stat($self->{name});

     ### check permissions
     if ((!defined($self->{stat})
          || ($self->{mode} != -1
           && ($self->{stat}->mode & 07777) != $self->{mode})))
     {
		$self->{changed} = 1;
		return 1;
     }

	return 0;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::ChMod - file-copy action class for PSGConf

=head1 SYNOPSIS

  use PSGConf::Action::ChMod;

  $psgconf->register_actions(
		PSGConf::Action::ChMod->new(
			'name'		=> '/path/to/file',
			'mode'		=> 'mode of file',
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::ChMod> module provides a B<PSGConf> action
class for creating an empty file if it does not already exist.

The B<PSGConf::Action::ChMod> class is derived from the
B<PSGConf::Action::File> class, but it defines/overrides the
following methods:

=over 4

=item check()

If the file mode is correct, returns 0.  Otherwise, returns 1.

=item diff()

Displays a message indicating that the file needs to be chmod()ed.

=back

=head1 SEE ALSO

L<perl>

L<chmod(1)>

L<PSGConf>

L<PSGConf::Action::File>

=cut

