
###
###  Copyright 2000-2005 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  PSGConf::Action::CreateFile - create file action type for psgconf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::CreateFile;

use strict;

use File::Copy;

use PSGConf::Action::File;

our @ISA = qw(PSGConf::Action::File);


###############################################################################
###  check method
###############################################################################

sub check
{
	my ($self, $psgconf) = @_;

	return $self->_file_mode_changed()
		if (-e $self->{name});

	$self->_set_tmpfile($psgconf);

	if (!copy('/dev/null', $self->{tmpfile}))
	{
		warn "\n\t!!! can't copy '/dev/null' to tempfile.\n";
		return -1;
	}

	$self->{changed} = 1;
	return 1;
}


###############################################################################
###  diff method
###############################################################################

sub diff
{
	my ($self, $psgconf) = @_;

	print "###############################################################################\n";
	print "### DIFF FOR $self->{name}\n";
	print "###############################################################################\n";
	print "+ create file: $self->{name}\n";
	print "\n";
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::CreateFile - create file action type for PSGConf

=head1 SYNOPSIS

  use PSGConf::Action::CreateFile;

  $psgconf->register_actions(
		PSGConf::Action::CreateFile->new(
			'name'		=> '/path/to/file',
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::CreateFile> module provides a B<PSGConf> action
class for creating an empty file if it does not already exist.

The B<PSGConf::Action::CreateFile> class is derived from the
B<PSGConf::Action::File> class, but it defines/overrides the
following methods:

=over 4

=item check()

If the file already exists, returns 0.  Otherwise, creates an empty
tmpfile and returns 1.

=item diff()

Displays a message indicating that the file needs to be created.

=back

=head1 BUGS

Used to be named PSGConf::Action::TouchFile, but does not work like
the L<touch(1)> command, hence the name change.

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::File>

=cut

