
###
###  Copyright 2000-2005 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  etc_services.pm - psgconf action class for generating /etc/services
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::etc_services;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  sort function
###############################################################################

sub _port_sort
{
	my ($a_num, $a_proto) = split('/', $a);
	my ($b_num, $b_proto) = split('/', $b);
	my $ret = ($a_num <=> $b_num);
	return ($ret == 0 ? $a_proto cmp $b_proto : $ret);
}


###############################################################################
###  generate() method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;
	my ($port);

	foreach $port (sort _port_sort keys %{$self->{port_names}})
	{
		printf $fh '%-15s %15s', $self->{port_names}->{$port}, $port;
		print $fh '   ' . join(' ', sort keys %{$self->{port_aliases}->{$port}})
			if (exists($self->{port_aliases}->{$port}));
		print $fh "\n";
	}

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::etc_services - action to generate /etc/services

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::etc_services;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::etc_services->new(
			'name'		=> '/etc/services',
			'port_names'	=> '...',
			'port_aliases'	=> '...',
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::etc_services> module provides a
B<PSGConf> action class for generating the F</etc/services> file.

The B<PSGConf::Action::GenerateFile::etc_services> class is derived from
the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generates the F</etc/services> file based on the value of the
I<port_names> and I<port_aliases> attributes.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::etc_services> class supports the
following attributes:

=over 4

=item I<port_names>

A reference to a hash that maps port numbers (e.g., "25/tcp") to a
primary port name.

=item I<port_aliases>

A reference to a hash that maps port numbers (e.g., "25/tcp") to a
list of port aliases.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


