
###
###  Copyright 2000-2005 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  PSGConf::Control::Library::ld.so.conf - class for configuring /etc/ld.so.conf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Control::Library::ld_so_conf;

use strict;

###############################################################################
###  constructor
###############################################################################

sub new
{
  my ($class, $psgconf) = @_;
  my ($self);
  
  $self = {};
  
  bless($self, $class);
  
  $self->{name} = 'ld.so.conf';
  
  $psgconf->register_data(
			  'ld_so_library_path_list'	=> PSGConf::Data::List->new(),
			  'ld_so_enable' => PSGConf::Data::Boolean->new()
			  );
  
  return $self;
}

sub decide
{
  my ($self, $psgconf) = @_;
  my ($content);
      
  $content = join("\n", @{$psgconf->ld_so_library_path_list}) . "\n";

  return if $content eq "\n";
  
  $psgconf->register_actions(
			     PSGConf::Action::GenerateFile::Literal->new(
									 name	=> '/etc/ld.so.conf',
									 content  => $content
									 )
		);
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Control::Library::ld_so_conf - psgconf control class for controlling dynamic library loader library locations

=head1 SYNOPSIS

In F<psgconf_modules>:

  Control PSGConf::Control::Library::ld_so_conf

=head1 DESCRIPTION

The B<PSGConf::Control::Library::ld_so_conf> module provides a B<psgconf> control object
for setting the dynamic library loader library load paths.
It supports the following methods:

=over 4

=item new()

The constructor.  Its parameter is a reference to the B<PSGConf>
object.  It registers the following data objects:

=over 4

=item I<ld_so_library_path_list>

A B<PSGConf::Data::List> object whose keys are the paths to directories to
be added to the library search path.

=item I<crle_enable>

A B<PSGConf::Data::Boolean> object to enable/disable this feature
    
=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile::Literal>

L<PSGConf::Data::List>

L<psgconf-intro>

=cut
